@@ -12,6 +12,8 @@ class Analytical:
             Offset value. Defaults to 0.0.
         seed (int):
             Seed value for random number generation. Defaults to 126.
+        fun_control (dict):
+            Dictionary containing control parameters for the function. Defaults to None.
 
     Notes:
         See [Numpy Random Sampling](https://numpy.org/doc/stable/reference/random/index.html#random-quick-start)
@@ -29,12 +31,22 @@ class Analytical:
             Dictionary containing control parameters for the function.
     """
 
-    def __init__(self, offset: float = 0.0, sigma=0.0, seed: int = 126) -> None:
+    def __init__(self, offset: float = 0.0, sigma=0.0, seed: int = 126, fun_control=None) -> None:
         self.offset = offset
         self.sigma = sigma
         self.seed = seed
         self.rng = default_rng(seed=self.seed)
-        self.fun_control = {"sigma": sigma, "seed": None, "sel_var": None}
+        self.fun_control = {"offset": offset, "sigma": self.sigma, "seed": self.seed}
+        # overwrite fun_control with user input if provided
+        if fun_control is not None:
+            self.fun_control = fun_control
+        # check if fun_control contains offset, sigma and seed, if not, add them
+        if "offset" not in self.fun_control:
+            self.fun_control["offset"] = self.offset
+        if "sigma" not in self.fun_control:
+            self.fun_control["sigma"] = self.sigma
+        if "seed" not in self.fun_control:
+            self.fun_control["seed"] = self.seed
 
     def __repr__(self) -> str:
         return f"analytical(offset={self.offset}, sigma={self.sigma}, seed={self.seed})"
@@ -142,19 +154,67 @@ class Analytical:
                 dict with entries `sigma` (noise level) and `seed` (random seed).
 
         Returns:
-            np.ndarray: A 1D numpy array with shape (n,) containing the calculated values.
+            np.ndarray: A 1D numpy array with shape (n,) containing the calculated values, which were obtained by
+            summing the weighted input values after subtracting the offset. Noise can be added to the output. An intercept
+            can be provided by setting the `alpha` key in the `fun_control` dictionary. If the `beta` key is provided, the
+            weighted sum is computed. If `beta` is not provided, the sum of the input values is computed.
 
         Examples:
-            >>> from spotpython.fun.objectivefunctions import analytical
+            >>> from spotpython.fun.objectivefunctions import Analytical
             >>> import numpy as np
-            >>> X = np.array([[1, 2, 3], [4, 5, 6]])
-            >>> fun = analytical()
-            >>> fun.fun_linear(X)
-            array([ 6., 15.])
+            >>> # Without offset and without noise
+            >>> user_fun = UserAnalytical()
+            >>> X = np.array([[0, 0, 0], [1, 1, 1]])
+            >>> results = user_fun.fun_user_function(X)
+            >>> print(results)
+            >>>
+            >>> # With offset and without noise
+            >>> user_fun = UserAnalytical(offset=1.0)
+            >>> X = np.array([[0, 0, 0], [1, 1, 1]])
+            >>> results = user_fun.fun_user_function(X)
+            >>> print(results)
+            >>>
+            >>> # With offset and noise
+            >>> user_fun = UserAnalytical(offset=1.0, sigma=0.1, seed=1)
+            >>> X = np.array([[0, 0, 0], [1, 1, 1]])
+            >>> results = user_fun.fun_user_function(X)
+            >>> print(results)
+            >>>
+            >>> # Provide alpha (intercept), no beta
+            >>> fun_control = {"alpha": 10.0}
+            >>> fun.fun_linear(X, fun_control=fun_control)
+            >>> array([16., 25.])
+            >>>
+            >>> # Provide alpha and beta (weighted sum with intercept)
+            >>> fun_control = {"alpha": 2.0, "beta": [1.0, 2.0, 3.0]}
+            >>> fun.fun_linear(X, fun_control=fun_control)
+            array([14., 32.])
+                [0. 3.]
+                [3. 0.]
+                [3.03455842 0.08216181]
 
         """
         X = self._prepare_input_data(X, fun_control)
-        y = np.sum(X, axis=1)
+        offset = np.ones(X.shape[1]) * self.offset
+
+        alpha = self.fun_control.get("alpha", 0.0)
+        beta = self.fun_control.get("beta", None)
+        if beta is not None:
+            # check if beta is a numpy array
+            if not isinstance(beta, np.ndarray):
+                # convert beta to numpy array of shape (n,), where n is the number of columns in X
+                beta = np.array(beta)
+            if beta.shape[0] != X.shape[1]:
+                raise Exception("beta must have the same number of elements as the number of columns in X")
+
+        # Compute the linear response
+        if beta is not None:
+            # Weighted sum with intercept
+            y = alpha + np.dot(X - offset, beta)
+        else:
+            # Original behavior: just sum the rows
+            y = alpha + np.sum(X - offset, axis=1)
+
         return self._add_noise(y)
 
     def fun_sphere(self, X: np.ndarray, fun_control: Optional[Dict] = None) -> np.ndarray:
@@ -380,14 +440,17 @@ class Analytical:
         y = 1 / (1 + sum_squared_diff)
         return self._add_noise(y)
 
-    def fun_wingwt(self, X: np.ndarray, fun_control: Optional[Dict] = None) -> np.ndarray:
+    def fun_wingwt_to_nat(self, X: np.ndarray, fun_control: Optional[Dict] = None) -> np.ndarray:
         r"""Wing weight function.
+        Converts coded values to natural values, before applying the original `fun_wingwt` function (Eq. 1.4 in [Forr08a]).
         Calculate the weight of an unpainted light aircraft wing based on design and operational parameters.
         This function implements the wing weight model from Forrester et al., which aims to predict
         the wing weight \( W \) using the following formula:
 
         \[
-        W = 0.036 \times S_W^{0.758} \times W_{fw}^{0.0035} \times \left( \frac{A}{\cos^2 \Lambda} \right)^{0.6} \times q^{0.006} \times \lambda^{0.04} \times \left( \frac{100 \times R_{tc}}{\cos \Lambda} \right)^{-0.3} \times (N_z \times W_{dg})^{0.49} + S_W \times W_p
+        W = 0.036 \times S_W^{0.758} \times W_{fw}^{0.0035} \times \left( \frac{A}{\cos^2 \Lambda} \right)^{0.6}
+        \times q^{0.006} \times \lambda^{0.04} \times \left( \frac{100 \times R_{tc}}{\cos \Lambda} \right)^{-0.3}
+        \times (N_z \times W_{dg})^{0.49} + S_W \times W_p
         \]
 
         where:
@@ -415,8 +478,8 @@ class Analytical:
         | \( \lambda \) | Taper ratio                            | 0.672    | 0.5     | 1       |
         | \( R_{tc} \)  | Aerofoil thickness to chord ratio      | 0.12     | 0.08    | 0.18    |
         | \( N_z \)     | Ultimate load factor                   | 3.8      | 2.5     | 6       |
-        | \( W_{dg} \)  | Flight design gross weight (lb)         | 2000     | 1700    | 2500    |
-        | \( W_p \)     | Paint weight \((\text{lb/ft}^2)\)                  | 0.064 |   0.025  | 0.08    |
+        | \( W_{dg} \)  | Flight design gross weight (lb)        | 2000     | 1700    | 2500    |
+        | \( W_p \)     | Paint weight \((\text{lb/ft}^2)\)      | 0.064 |   0.025  | 0.08    |
 
         Args:
             X (np.ndarray):
@@ -449,8 +512,93 @@ class Analytical:
         Wdg = X[:, 8] * 800 + 1700  # equivalent to (2500 - 1700) + 1700
         Wp = X[:, 9] * 0.055 + 0.025  # equivalent to (0.08 - 0.025) + 0.025
         # Calculate W for all rows in a vectorized manner
-        W = 0.036 * Sw**0.758 * Wfw**0.0035 * (A / np.cos(L) ** 2) ** 0.6 * q**0.006
-        W *= la**0.04 * (100 * Rtc / np.cos(L)) ** (-0.3) * (Nz * Wdg) ** (0.49)
+        W = 0.036 * Sw**0.758 * Wfw**0.0035
+        W *= (A / np.cos(L) ** 2) ** 0.6 * q**0.006
+        W *= la**0.04
+        print(f"W: {W}")
+        print(f"(100 * Rtc / np.cos(L)): {(100 * Rtc / np.cos(L))}")
+        W *= (100 * Rtc / np.cos(L)) ** (-0.3)
+        print(f"W: {W}")
+        W *= (Nz * Wdg) ** (0.49)
+        W += Sw * Wp
+        return self._add_noise(y=W)
+
+    def fun_wingwt(self, X: np.ndarray, fun_control: Optional[Dict] = None) -> np.ndarray:
+        r"""Wing weight function. Returns coded, not natural values.
+        Calculate the weight of an unpainted light aircraft wing based on design and operational parameters.
+        This function implements the wing weight model from Forrester et al., which aims to predict
+        the wing weight \( W \) using the following formula:
+
+        \[
+        W = 0.036 \times S_W^{0.758} \times W_{fw}^{0.0035} \times \left( \frac{A}{\cos^2 \Lambda} \right)^{0.6}
+        \times q^{0.006} \times \lambda^{0.04} \times \left( \frac{100 \times R_{tc}}{\cos \Lambda} \right)^{-0.3}
+        \times (N_z \times W_{dg})^{0.49} + S_W \times W_p
+        \]
+
+        where:
+
+        - \( S_W \): Wing area \((\text{ft}^2)\)
+        - \( W_{fw} \): Weight of fuel in the wing (lb)
+        - \( A \): Aspect ratio
+        - \( \Lambda \): Quarter-chord sweep (degrees)
+        - \( q \): Dynamic pressure at cruise \((\text{lb/ft}^2)\)
+        - \( \lambda \): Taper ratio
+        - \( R_{tc} \): Aerofoil thickness to chord ratio
+        - \( N_z \): Ultimate load factor
+        - \( W_{dg} \): Flight design gross weight (lb)
+        - \( W_p \): Paint weight \((\text{lb/ft}^2)\)
+
+        Parameter Overview:
+
+        | Symbol    | Parameter                              | Baseline | Minimum | Maximum |
+        |-----------|----------------------------------------|----------|---------|---------|
+        | \( S_W \)     | Wing area \((\text{ft}^2)\)            | 174      | 150     | 200     |
+        | \( W_{fw} \)  | Weight of fuel in wing (lb)            | 252      | 220     | 300     |
+        | \( A \)       | Aspect ratio                          | 7.52     | 6       | 10      |
+        | \( \Lambda \) | Quarter-chord sweep (deg)              | 0        | -10     | 10      |
+        | \( q \)       | Dynamic pressure at cruise \((\text{lb/ft}^2)\) | 34       | 16      | 45      |
+        | \( \lambda \) | Taper ratio                            | 0.672    | 0.5     | 1       |
+        | \( R_{tc} \)  | Aerofoil thickness to chord ratio      | 0.12     | 0.08    | 0.18    |
+        | \( N_z \)     | Ultimate load factor                   | 3.8      | 2.5     | 6       |
+        | \( W_{dg} \)  | Flight design gross weight (lb)        | 2000     | 1700    | 2500    |
+        | \( W_p \)     | Paint weight \((\text{lb/ft}^2)\)      | 0.064 |   0.025  | 0.08    |
+
+        Args:
+            X (np.ndarray):
+                A 2D numpy array where each row contains 10 parameters for which the wing weight will be calculated.
+            fun_control (Optional[Dict]):
+                A dictionary with keys `sigma` (noise level) and `seed` (random seed)
+                for incorporating randomness if required. Default is `None`.
+
+        Returns:
+            np.ndarray:
+            A 1D numpy array with shape (n,) containing the calculated wing weight values.
+
+        Examples:
+            >>> from spotpython.fun.objectivefunctions import analytical
+            >>> import numpy as np
+            >>> X = np.array([np.zeros(10), np.ones(10)])
+            >>> fun = analytical()
+            >>> fun.fun_wingwt(X)
+            array([158.28245046, 409.33182691])
+        """
+        X = self._prepare_input_data(X, fun_control)
+        Sw = X[:, 0]
+        Wfw = X[:, 1]
+        A = X[:, 2]
+        L = X[:, 3] * np.pi / 180
+        q = X[:, 4]
+        la = X[:, 5]
+        Rtc = X[:, 6]
+        Nz = X[:, 7]
+        Wdg = X[:, 8]
+        Wp = X[:, 9]
+        # Calculate W for all rows in a vectorized manner
+        W = 0.036 * Sw**0.758 * Wfw**0.0035
+        W *= (A / np.cos(L) ** 2) ** 0.6 * q**0.006
+        W *= la**0.04
+        W *= (100 * Rtc / np.cos(L)) ** (-0.3)
+        W *= (Nz * Wdg) ** (0.49)
         W += Sw * Wp
         return self._add_noise(y=W)
 
