@@ -187,7 +187,8 @@ def get_dict_with_levels_and_types(fun_control: Dict[str, Any], v: Dict[str, Any
     Examples:
             >>> from spotpython.hyperdict.light_hyper_dict import LightHyperDict
                 from spotpython.hyperparameters.values import get_default_hyperparameters_as_array
-                from spotpython.hyperparameters.values import assign_values, get_var_name, iterate_dict_values, convert_keys, get_dict_with_levels_and_types, get_core_model_from_name, add_core_model_to_fun_control
+                from spotpython.hyperparameters.values import (assign_values, get_var_name, iterate_dict_values,
+                    convert_keys, get_dict_with_levels_and_types, get_core_model_from_name, add_core_model_to_fun_control)
                 import pprint
                 core_model_name="light.regression.NNLinearRegressor"
                 hyperdict=LightHyperDict
@@ -464,7 +465,9 @@ def get_tuned_architecture(spot_tuner, force_minX=False) -> dict:
             from spotpython.utils.init import fun_control_init, design_control_init
             from spotpython.spot import Spot
             import numpy as np
-            from spotpython.hyperparameters.values import set_hyperparameter, get_one_config_from_X
+            from spotpython.hyperparameters.values import set_hyperparameter, get_tuned_architecture
+
+
             fun_control = fun_control_init(
                 force_run=False,
                 PREFIX="get_one_config_from_X",
@@ -476,24 +479,22 @@ def get_tuned_architecture(spot_tuner, force_minX=False) -> dict:
                 hyperdict=LightHyperDict,
                 _L_in=10,
                 _L_out=1)
-            # Uncomment the following lines to perform the hyperparameter optimization:
-            # set_hyperparameter(fun_control, "epochs", [2,3])
-            # set_hyperparameter(fun_control, "patience", [1,2])
-            # design_control = design_control_init(init_size=5)
-            # fun = HyperLight().fun
-            # S = Spot(fun=fun,fun_control=fun_control, design_control=design_control)
-            # S.run()
-            # X = S.to_all_dim(S.min_X.reshape(1, -1))
-            # Otherwise, only take the result:
-            X = np.array([[ 4., 2., 1., 3.,  11., 0.03480567, 7.98104224,  1., 1., 0.]])
-            get_one_config_from_X(X, fun_control)
-               {'l1': 16,
+
+            set_hyperparameter(fun_control, "epochs", [2,3])
+            set_hyperparameter(fun_control, "patience", [1,2])
+            design_control = design_control_init(init_size=5)
+
+            fun = HyperLight().fun
+            S = Spot(fun=fun,fun_control=fun_control, design_control=design_control)
+            S.run()
+            get_tuned_architecture(S)
+                {'l1': 16,
                 'epochs': 4,
                 'batch_size': 2,
                 'act_fn': LeakyReLU(),
                 'optimizer': 'SGD',
-                'dropout_prob': 0.03480567,
-                'lr_mult': 7.98104224,
+                'dropout_prob': 0.034805674424520705,
+                'lr_mult': 7.981042243396318,
                 'patience': 2,
                 'batch_norm': True,
                 'initialization': 'Default'}
@@ -503,45 +504,11 @@ def get_tuned_architecture(spot_tuner, force_minX=False) -> dict:
     else:
         # noise or force_minX is False:
         X = spot_tuner.to_all_dim(spot_tuner.min_mean_X.reshape(1, -1))
-        fun_control = copy(spot_tuner.fun_control)
+    fun_control = copy.copy(spot_tuner.fun_control)
     config = get_one_config_from_X(X, fun_control)
     return config
 
 
-def return_conf_list_from_var_dict(
-    var_dict: Dict[str, np.ndarray],
-    fun_control: Dict[str, Union[List[str], str]],
-    default: bool = False,
-) -> List[Dict[str, Union[int, float]]]:
-    """Return a list of configurations from a dictionary of variables.
-
-    This function takes a dictionary of variables and a dictionary of function control as input arguments.
-    It performs similar steps as generate_one_config_from_var_dict() but returns a list of dictionaries
-    of hyper parameter values.
-
-    Args:
-        var_dict (dict): A dictionary where keys are variable names and values are numpy arrays.
-        fun_control (dict): A dictionary which (at least) has an entry with the following key:
-            "var_type" (list): A list of variable types. If the entry is not "num" the corresponding
-            value will be converted to the type "int".
-
-    Returns:
-        list: A list of dictionaries of hyper parameter values. Transformations are applied to the values.
-
-    Examples:
-        >>> import numpy as np
-        >>> from spotpython.hyperparameters.values import return_conf_list_from_var_dict
-        >>> var_dict = {'a': np.array([1, 3, 5]), 'b': np.array([2, 4, 6])}
-        >>> fun_control = {'var_type': ['int', 'int']}
-        >>> return_conf_list_from_var_dict(var_dict, fun_control)
-        [{'a': 1, 'b': 2}, {'a': 3, 'b': 4}, {'a': 5, 'b': 6}]
-    """
-    conf_list = []
-    for values in generate_one_config_from_var_dict(var_dict, fun_control, default=default):
-        conf_list.append(values)
-    return conf_list
-
-
 def modify_boolean_hyper_parameter_levels(fun_control, hyperparameter, levels) -> None:
     """
     This function modifies the levels of a boolean hyperparameter in the fun_control dictionary.
@@ -1636,16 +1603,16 @@ def set_int_hyperparameter_values(fun_control, key, lower, upper) -> None:
         >>> from spotriver.hyperdict.river_hyper_dict import RiverHyperDict
             from spotpython.utils.init import fun_control_init
             from spotpython.hyperparameters.values import set_int_hyperparameter_values
-            from spotpython.utils.eda import gen_design_table
+            from spotpython.utils.eda import print_exp_table
             fun_control = fun_control_init(
                 core_model_name="forest.AMFRegressor",
                 hyperdict=RiverHyperDict,
             )
             print("Before modification:")
-            print(gen_design_table(fun_control))
+            print_exp_table(fun_control)
             set_int_hyperparameter_values(fun_control, "n_estimators", 2, 5)
             print("After modification:")
-            print(gen_design_table(fun_control))
+            print_exp_table(fun_control)
             Seed set to 123
                 Before modification:
                 | name            | type   |   default |   lower |   upper | transform   |
@@ -1692,16 +1659,16 @@ def set_float_hyperparameter_values(fun_control, key, lower, upper) -> None:
         >>> from spotriver.hyperdict.river_hyper_dict import RiverHyperDict
             from spotpython.utils.init import fun_control_init
             from spotpython.hyperparameters.values import set_float_hyperparameter_values
-            from spotpython.utils.eda import gen_design_table
+            from spotpython.utils.eda import print_exp_table
             fun_control = fun_control_init(
                 core_model_name="forest.AMFRegressor",
                 hyperdict=RiverHyperDict,
             )
             print("Before modification:")
-            print(gen_design_table(fun_control))
+            print_exp_table(fun_control)
             set_float_hyperparameter_values(fun_control, "step", 0.2, 5)
             print("After modification:")
-            print(gen_design_table(fun_control))
+            print_exp_table(fun_control)
             Seed set to 123
     """
     set_control_hyperparameter_value(
@@ -1732,16 +1699,16 @@ def set_boolean_hyperparameter_values(fun_control, key, lower, upper):
         >>> from spotriver.hyperdict.river_hyper_dict import RiverHyperDict
             from spotpython.utils.init import fun_control_init
             from spotpython.hyperparameters.values import set_boolean_hyperparameter_values
-            from spotpython.utils.eda import gen_design_table
+            from spotpython.utils.eda import print_exp_table
             fun_control = fun_control_init(
                 core_model_name="forest.AMFRegressor",
                 hyperdict=RiverHyperDict,
             )
             print("Before modification:")
-            print(gen_design_table(fun_control))
+            print_exp_table(fun_control)
             set_boolean_hyperparameter_values(fun_control, "use_aggregation", 0, 0)
             print("After modification:")
-            print(gen_design_table(fun_control))
+            print_exp_table(fun_control)
             Seed set to 123
             Before modification:
             | name            | type   |   default |   lower |   upper | transform   |
@@ -1786,17 +1753,17 @@ def set_factor_hyperparameter_values(fun_control, key, levels):
         >>> from spotriver.hyperdict.river_hyper_dict import RiverHyperDict
             from spotpython.utils.init import fun_control_init
             from spotpython.hyperparameters.values import set_factor_hyperparameter_values
-            from spotpython.utils.eda import gen_design_table
+            from spotpython.utils.eda import print_exp_table
             fun_control = fun_control_init(
                 core_model_name="tree.HoeffdingTreeRegressor",
                 hyperdict=RiverHyperDict,
             )
             print("Before modification:")
-            print(gen_design_table(fun_control))
+            print_exp_tablefun_control)
             set_factor_hyperparameter_values(fun_control, "leaf_model", ['LinearRegression',
                                                                 'Perceptron'])
             print("After modification:")
-            print(gen_design_table(fun_control))
+            print_exp_table(fun_control))
                 Seed set to 123
                 Before modification:
                 | name                   | type   | default          |   lower |    upper | transform              |
